@@ -159,39 +159,14 @@ function(x, nu, xi)
 # ------------------------------------------------------------------------------
 
 
-.psged_orig <- 
-function(q, nu, xi) 
-{   
-    # A function implemented by Diethelm Wuertz 
-
-    # Description:
-    #   Internal Function
-    
-    # FUNCTION:
-    
-    # Standardize:
-    lambda = sqrt ( 2^(-2/nu) * gamma(1/nu) / gamma(3/nu) )
-    g  = nu / ( lambda * (2^(1+1/nu)) * gamma(1/nu) )
-    m1 = 2^(1/nu) * lambda * gamma(2/nu) / gamma(1/nu)
-    mu = m1*(xi-1/xi)
-    sigma =  sqrt((1-m1^2)*(xi^2+1/xi^2) + 2*m1^2 - 1)
-    z = q*sigma + mu
-    
-    # Compute:  
-    Xi = xi^sign(z)
-    g = 2  / (xi + 1/xi)    
-    Probability = Heaviside(z) - sign(z) * g * Xi * pged(q = -abs(z)/Xi, nu=nu)
-    
-    # Return Value:
-    Probability 
-}
-
-
 .psged <- 
 function(q, nu, xi) 
 {   
     # A function implemented by Diethelm Wuertz 
-
+    ##
+    ## fixed by GNB, see section 'CHANGES in fGarch VERSION 4021.87, 2022-08-06', subsection
+    ## 'BUG fixes' in NEWS.Rd.
+    
     # Description:
     #   Internal Function
     
@@ -219,38 +194,13 @@ function(q, nu, xi)
 # ------------------------------------------------------------------------------
 
 
-.qsged_orig <- 
-function(p, nu, xi) 
-{   
-    # A function implemented by Diethelm Wuertz 
-
-    # Description:
-    #   Internal Function
-    
-    # FUNCTION:
-    
-    # Standardize:
-    lambda = sqrt ( 2^(-2/nu) * gamma(1/nu) / gamma(3/nu) )
-    g  = nu / ( lambda * (2^(1+1/nu)) * gamma(1/nu) )
-    m1 = 2^(1/nu) * lambda * gamma(2/nu) / gamma(1/nu)
-    mu = m1*(xi-1/xi)
-    sigma =  sqrt((1-m1^2)*(xi^2+1/xi^2) + 2*m1^2 - 1)
-    
-    # Compute:  
-    g = 2  / (xi + 1/xi)
-    sig = sign(p-1/2) 
-    Xi = xi^sig       
-    p = (Heaviside(p-1/2)-sig*p) / (g*Xi)
-    Quantile = (-sig*qged(p=p, sd=Xi, nu=nu) - mu ) / sigma
-    
-    # Return Value:
-    Quantile 
-}
-
 .qsged <- 
 function(p, nu, xi) 
 {   
     # A function implemented by Diethelm Wuertz 
+    ##
+    ## fixed by GNB, see section 'CHANGES in fGarch VERSION 4021.87, 2022-08-06', subsection
+    ## 'BUG fixes' in NEWS.Rd.
 
     # Description:
     #   Internal Function
